@@ -17,7 +17,7 @@ package SDCommon;
 use base qw/ Exporter /;
 our @EXPORT = qw(writeCfg withecho withechoNoPrompt needs_upsTagUrl
 needs_upsCurrentUrl needs_tagsUrl url insvn long_path oldSvnDirsCheck
-load_dirs set_statusref svnMkdirP start_ssh _g);
+load_dirs set_statusref svnMkdirP start_ssh _g rev_number);
 #### common ####
 our @EXPORT_OK = qw ($tagVersion $upVersion $package $version
 $opt_verbose $opt_noninteractive %c $opt_nosave $opt_quiet $epoch
@@ -54,15 +54,8 @@ sub common_version {
 
 $SDCommon::version=&common_version();
 
-# workaround for the old piece of Perl shit in Woody
 sub long_path {
-   if( ($] cmp "5.008") >= 0) {
-      return Cwd::abs_path($_[0]);
-   }
-   use File::Basename;
-   return $_[0] if (! -r $_[0]);
-   return Cwd::abs_path(dirname($_[0]))."/".basename($_[0]); # would break on symlinks but get a newer perl if you wanna fix it
-   #   ( (-l $_[0]) ? readlink($_[0]) : $_[0]);
+   return Cwd::abs_path($_[0]);
 }
 
 my $cfgFile=long_path(".svn/deb-layout");
@@ -183,6 +176,17 @@ sub oldSvnDirsCheck {
    }
 }
 
+sub rev_number {
+   my $Revision;
+   my $testpath=long_path("./debian/");
+   open(INFO, "env LC_ALL=C svnversion $testpath 2>/dev/null |");
+   while(<INFO>) {
+      chomp;
+      s/.*:// if (/:/);
+      $Revision=$1 if (/^([0-9]+)M?$/i);
+   };
+   return $Revision;
+}
 
 # gets the url of specified local (checkout) directory
 sub url {
@@ -610,8 +614,8 @@ sub collect_name {
 #    return (keys %tmp);
 #}
 
-# embedd new contents into an URL-referenced directory, using a specified
-# work directory. The resulting directory is not commited, check and commit
+# embed new contents into an URL-referenced directory, using a specified
+# work directory. The resulting directory is not commited; check and commit
 # yourself with appropriate message.
 sub load_dirs {
     my $url=shift;
@@ -668,7 +672,7 @@ sub load_dirs {
               $ctx->add($_, 1) if $SDCommon::opt_ignored_files_action eq "import";
            } else {
               unless ($SDCommon::opt_noninteractive) {
-                 printf STDERR _g("One or more files are ignore due to (global) subversion ignore patterns,\n\thow to procede (quit, import, skip)? [Qis?]: ");
+                 printf STDERR _g("One or more files were ignored due to (global) subversion svn:ignore properties,\n\thow to procede (quit, import, skip)? [Qis?]: ");
                  prompt:
                  my $ans = <STDIN>;
                  exwerror sprintf (_g("Aborting!\n")) if ($ans =~ /^$/ or $ans =~ /^q/i);
